@@ -40,8 +40,8 @@ Button::Button(DecorationButtonType type, Decoration *decoration, QObject *paren
     setIconSize(QSize(height, height));
 
     // connections
-    connect(decoration->client().toStrongRef().data(), SIGNAL(iconChanged(QIcon)), this, SLOT(update()));
-    connect(decoration->settings().data(), &KDecoration2::DecorationSettings::reconfigured, this, &Button::reconfigure);
+    connect(decoration->client(), SIGNAL(iconChanged(QIcon)), this, SLOT(update()));
+    connect(decoration->settings().get(), &KDecoration2::DecorationSettings::reconfigured, this, &Button::reconfigure);
     connect(this, &KDecoration2::DecorationButton::hoveredChanged, this, &Button::updateAnimationState);
 
     reconfigure();
@@ -62,35 +62,35 @@ Button *Button::create(DecorationButtonType type, KDecoration2::Decoration *deco
 {
     if (auto d = qobject_cast<Decoration *>(decoration)) {
         Button *b = new Button(type, d, parent);
-        const auto c = d->client().toStrongRef();
+        const auto c = d->client();
         switch (type) {
         case DecorationButtonType::Close:
             b->setVisible(c->isCloseable());
-            QObject::connect(c.data(), &KDecoration2::DecoratedClient::closeableChanged, b, &Breeze::Button::setVisible);
+            QObject::connect(c, &KDecoration2::DecoratedClient::closeableChanged, b, &Breeze::Button::setVisible);
             break;
 
         case DecorationButtonType::Maximize:
             b->setVisible(c->isMaximizeable());
-            QObject::connect(c.data(), &KDecoration2::DecoratedClient::maximizeableChanged, b, &Breeze::Button::setVisible);
+            QObject::connect(c, &KDecoration2::DecoratedClient::maximizeableChanged, b, &Breeze::Button::setVisible);
             break;
 
         case DecorationButtonType::Minimize:
             b->setVisible(c->isMinimizeable());
-            QObject::connect(c.data(), &KDecoration2::DecoratedClient::minimizeableChanged, b, &Breeze::Button::setVisible);
+            QObject::connect(c, &KDecoration2::DecoratedClient::minimizeableChanged, b, &Breeze::Button::setVisible);
             break;
 
         case DecorationButtonType::ContextHelp:
             b->setVisible(c->providesContextHelp());
-            QObject::connect(c.data(), &KDecoration2::DecoratedClient::providesContextHelpChanged, b, &Breeze::Button::setVisible);
+            QObject::connect(c, &KDecoration2::DecoratedClient::providesContextHelpChanged, b, &Breeze::Button::setVisible);
             break;
 
         case DecorationButtonType::Shade:
             b->setVisible(c->isShadeable());
-            QObject::connect(c.data(), &KDecoration2::DecoratedClient::shadeableChanged, b, &Breeze::Button::setVisible);
+            QObject::connect(c, &KDecoration2::DecoratedClient::shadeableChanged, b, &Breeze::Button::setVisible);
             break;
 
         case DecorationButtonType::Menu:
-            QObject::connect(c.data(), &KDecoration2::DecoratedClient::iconChanged, b, [b]() {
+            QObject::connect(c, &KDecoration2::DecoratedClient::iconChanged, b, [b]() {
                 b->update();
             });
             break;
@@ -130,7 +130,7 @@ void Button::paint(QPainter *painter, const QRect &repaintRegion)
     // menu button
     if (type() == DecorationButtonType::Menu) {
         const QRectF iconRect(geometry().topLeft(), m_iconSize);
-        const auto c = decoration()->client().toStrongRef();
+        const auto c = decoration()->client();
         if (auto deco = qobject_cast<Decoration *>(decoration())) {
             const QPalette activePalette = KIconLoader::global()->customPalette();
             QPalette palette = c->palette();
@@ -161,7 +161,7 @@ void Button::drawIcon(QPainter *painter) const
     /*
     scale painter so that its window matches QRect( -1, -1, 20, 20 )
     this makes all further rendering and scaling simpler
-    all further rendering is preformed inside QRect( 0, 0, 18, 18 )
+    all further rendering is performed inside QRect( 0, 0, 18, 18 )
     */
     painter->translate(geometry().topLeft());
 
@@ -332,7 +332,7 @@ QColor Button::backgroundColor() const
         return QColor();
     }
 
-    auto c = d->client().toStrongRef();
+    auto c = d->client();
     QColor redColor(c->color(ColorGroup::Warning, ColorRole::Foreground));
 
     if (isPressed()) {
