@@ -5,8 +5,7 @@
  * SPDX-License-Identifier: GPL-2.0-or-later
  */
 
-#ifndef breezemetrics_h
-#define breezemetrics_h
+#pragma once
 
 #include <QtGlobal>
 
@@ -133,7 +132,7 @@ struct Metrics {
     static constexpr int TabBar_BaseOverlap = 2;
 
     // tab widget
-    static constexpr int TabWidget_MarginWidth = 4;
+    static constexpr int TabWidget_MarginWidth = 3;
 
     // toolbox
     static constexpr int ToolBox_TabMinWidth = 80;
@@ -160,4 +159,3 @@ struct Metrics {
     static constexpr int Shadow_Overlap = 2;
 };
 }
-#endif
