@@ -71,7 +71,8 @@ void Mnemonics::setEnabled(bool value)
     _enabled = value;
 
     // update all top level widgets
-    foreach (QWidget *widget, qApp->topLevelWidgets()) {
+    const auto widgets = qApp->topLevelWidgets();
+    for (QWidget *widget : widgets) {
         widget->update();
     }
 }
