@@ -4,8 +4,7 @@
  * SPDX-License-Identifier: GPL-2.0-or-later
  */
 
-#ifndef breezestyle_h
-#define breezestyle_h
+#pragma once
 
 #include "breeze.h"
 #include "breezehelper.h"
@@ -281,6 +280,8 @@ private:
     bool drawIndicatorToolBarHandlePrimitive(const QStyleOption *, QPainter *, const QWidget *) const;
     bool drawIndicatorToolBarSeparatorPrimitive(const QStyleOption *, QPainter *, const QWidget *) const;
     bool drawIndicatorBranchPrimitive(const QStyleOption *, QPainter *, const QWidget *) const;
+    bool drawDockWidgetResizeHandlePrimitive(const QStyleOption *, QPainter *, const QWidget *) const;
+    bool drawPanelStatusBarPrimitive(const QStyleOption *, QPainter *, const QWidget *) const;
     bool drawWidgetPrimitive(const QStyleOption *, QPainter *, const QWidget *) const;
 
     //@}
@@ -316,6 +317,7 @@ private:
     bool drawToolBoxTabLabelControl(const QStyleOption *, QPainter *, const QWidget *) const;
     bool drawToolBoxTabShapeControl(const QStyleOption *, QPainter *, const QWidget *) const;
     bool drawDockWidgetTitleControl(const QStyleOption *, QPainter *, const QWidget *) const;
+    bool drawSplitterControl(const QStyleOption *, QPainter *, const QWidget *) const;
 
     //*@}
 
@@ -438,6 +440,10 @@ private:
         return QRect(rect.left() + (rect.width() - width) / 2, rect.top() + (rect.height() - height) / 2, width, height);
     }
 
+    static int sliderTickMarksLength();
+
+    static QRect sliderRectWithoutTickMarks(const QStyleOptionSlider *option);
+
     /*
     Checks whether the point is before the bound rect for bound of given orientation.
     This is needed to implement custom number of buttons in scrollbars,
@@ -584,5 +590,3 @@ bool Style::hasParent(const QWidget *widget, const char *className) const
     return false;
 }
 }
-
-#endif
