@@ -27,11 +27,12 @@ int main(int argc, char *argv[])
 
     KCMultiDialog dialog;
     dialog.setWindowTitle(i18n("Breeze Settings"));
-    dialog.addModule(KPluginMetaData(QStringLiteral("plasma/kcms/systemsettings_qwidgets/breezestyleconfig")));
+    dialog.addModule(KPluginMetaData(QStringLiteral("kstyle_config/breezestyleconfig")));
     dialog.addModule(KPluginMetaData(QStringLiteral("plasma/kcms/breeze/kcm_breezedecoration")));
     dialog.show();
 
-    foreach (auto child, dialog.findChildren<QAbstractScrollArea *>()) {
+    const auto children = dialog.findChildren<QAbstractScrollArea *>();
+    for (auto child : children) {
         child->adjustSize();
         child->viewport()->adjustSize();
     }
